@@ -9,13 +9,11 @@
  */
 #pragma once
 
+#include <config.h>
+
 #include <stdint.h>
 //#include "outputs.h"
 
-#ifdef XCB_COMPAT
-#define XCB_ATOM_CARDINAL CARDINAL
-#endif
-
 #define _NET_SYSTEM_TRAY_ORIENTATION_HORZ 0
 #define _NET_SYSTEM_TRAY_ORIENTATION_VERT 1
 #define SYSTEM_TRAY_REQUEST_DOCK 0
