@@ -9,8 +9,11 @@
  */
 #pragma once
 
+#include <config.h>
+
 #include <yajl/yajl_gen.h>
 
+SLIST_HEAD(variables_head, Variable);
 extern pid_t config_error_nagbar_pid;
 
 /*
