@@ -9,6 +9,8 @@
  */
 #pragma once
 
+#include <config.h>
+
 #include "data.h"
 
 /**
@@ -35,19 +37,3 @@ void restore_geometry(void);
 void manage_window(xcb_window_t window,
                    xcb_get_window_attributes_cookie_t cookie,
                    bool needs_to_be_mapped);
-
-#if 0
-/**
- * reparent_window() gets called when a new window was opened and becomes a
- * child of the root window, or it gets called by us when we manage the
- * already existing windows at startup.
- *
- * Essentially, this is the point where we take over control.
- *
- */
-void reparent_window(xcb_connection_t *conn, xcb_window_t child,
-                     xcb_visualid_t visual, xcb_window_t root, uint8_t depth,
-                     int16_t x, int16_t y, uint16_t width, uint16_t height,
-                     uint32_t border_width);
-
-#endif
