@@ -13,6 +13,8 @@
  */
 #pragma once
 
+#include <config.h>
+
 /*
  * Initializes the Match data structure. This function is necessary because the
  * members representing boolean values (like dock) need to be initialized with
@@ -45,3 +47,9 @@ bool match_matches_window(Match *match, i3Window *window);
  *
  */
 void match_free(Match *match);
+
+/**
+ * Interprets a ctype=cvalue pair and adds it to the given match specification.
+ *
+ */
+void match_parse_property(Match *match, const char *ctype, const char *cvalue);
