@@ -10,8 +10,12 @@
  */
 #pragma once
 
+#include <config.h>
+
 #include <stdint.h>
+#if !defined(__OpenBSD__)
 #include <pthread.h>
+#endif
 
 /* Default shmlog size if not set by user. */
 extern const int default_shmlog_size;
@@ -24,7 +28,7 @@ typedef struct i3_shmlog_header {
     /* Byte offset where the next line will be written to. */
     uint32_t offset_next_write;
 
-    /* Byte offset where the last wrap occured. */
+    /* Byte offset where the last wrap occurred. */
     uint32_t offset_last_wrap;
 
     /* The size of the logfile in bytes. Since the size is limited to 25 MiB
@@ -37,8 +41,10 @@ typedef struct i3_shmlog_header {
      * and don’t matter — clients use an equality check (==). */
     uint32_t wrap_count;
 
+#if !defined(__OpenBSD__)
     /* pthread condvar which will be broadcasted whenever there is a new
      * message in the log. i3-dump-log uses this to implement -f (follow, like
      * tail -f) in an efficient way. */
     pthread_cond_t condvar;
+#endif
 } i3_shmlog_header;
