@@ -9,6 +9,8 @@
  */
 #pragma once
 
+#include <config.h>
+
 extern Con *croot;
 /* TODO: i am not sure yet how much access to the focused container should
  * be permitted to source files */
@@ -56,12 +58,6 @@ bool level_down(void);
  */
 void tree_render(void);
 
-/**
- * Closes the current container using tree_close().
- *
- */
-void tree_close_con(kill_window_t kill_window);
-
 /**
  * Changes focus in the given way (next/previous) and given orientation
  * (horizontal/vertical).
@@ -78,11 +74,11 @@ void tree_next(char way, orientation_t orientation);
  * recursively while deleting a containers children.
  *
  * The force_set_focus flag is specified in the case of killing a floating
- * window: tree_close() will be invoked for the CT_FLOATINGCON (the parent
+ * window: tree_close_internal() will be invoked for the CT_FLOATINGCON (the parent
  * container) and focus should be set there.
  *
  */
-bool tree_close(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool force_set_focus);
+bool tree_close_internal(Con *con, kill_window_t kill_window, bool dont_kill_parent, bool force_set_focus);
 
 /**
  * Loads tree from ~/.i3/_restart.json (used for in-place restarts).
