@@ -10,6 +10,8 @@
  */
 #pragma once
 
+#include <config.h>
+
 #include "data.h"
 #include "tree.h"
 #include "randr.h"
@@ -50,17 +52,6 @@ void extract_workspace_names_from_bindings(void);
  */
 Con *create_workspace_on_output(Output *output, Con *content);
 
-#if 0
-/**
- * Sets the name (or just its number) for the given workspace. This has to
- * be called for every workspace as the rendering function
- * (render_internal_bar) relies on workspace->name and workspace->name_len
- * being ready-to-use.
- *
- */
-void workspace_set_name(Workspace *ws, const char *name);
-#endif
-
 /**
  * Returns true if the workspace is currently visible. Especially important for
  * multi-monitor environments, as they can have multiple currenlty active
