@@ -10,6 +10,8 @@
  */
 #pragma once
 
+#include <config.h>
+
 /** Stores the X11 window ID of the currently focused window */
 extern xcb_window_t focused_id;
 
@@ -18,7 +20,7 @@ extern xcb_window_t focused_id;
  * every container from con_new().
  *
  */
-void x_con_init(Con *con, uint16_t depth);
+void x_con_init(Con *con);
 
 /**
  * Moves a child window from Container src to Container dest.
