@@ -3,9 +3,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 0:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_rename_workspace(&current_match, result, NULL, get_string("new_name"));
+             cmd_rename_workspace(&current_match, result, "to", get_string("new_name"));
 #else
-           fprintf(stderr, "cmd_rename_workspace(NULL, %s)\n", get_string("new_name"));
+           fprintf(stderr, "cmd_rename_workspace(%s, %s)\n", "to", get_string("new_name"));
 #endif
              break;
          case 1:
@@ -27,25 +27,25 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 3:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_move_workspace_to_output(&current_match, result, get_string("output"));
+             cmd_rename_workspace(&current_match, result, NULL, get_string("new_name"));
 #else
-           fprintf(stderr, "cmd_move_workspace_to_output(%s)\n", get_string("output"));
+           fprintf(stderr, "cmd_rename_workspace(NULL, %s)\n", get_string("new_name"));
 #endif
              break;
          case 4:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_move_con_to_workspace_number(&current_match, result, get_string("number"), get_string("no_auto_back_and_forth"));
+             cmd_move_workspace_to_output(&current_match, result, get_string("output"));
 #else
-           fprintf(stderr, "cmd_move_con_to_workspace_number(%s, %s)\n", get_string("number"), get_string("no_auto_back_and_forth"));
+           fprintf(stderr, "cmd_move_workspace_to_output(%s)\n", get_string("output"));
 #endif
              break;
          case 5:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_resize(&current_match, result, get_string("way"), get_string("direction"), get_long("resize_px"), get_long("resize_ppt"));
+             cmd_move_con_to_workspace_number(&current_match, result, get_string("number"), get_string("no_auto_back_and_forth"));
 #else
-           fprintf(stderr, "cmd_resize(%s, %s, %ld, %ld)\n", get_string("way"), get_string("direction"), get_long("resize_px"), get_long("resize_ppt"));
+           fprintf(stderr, "cmd_move_con_to_workspace_number(%s, %s)\n", get_string("number"), get_string("no_auto_back_and_forth"));
 #endif
              break;
          case 6:
@@ -59,9 +59,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 7:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_move_window_to_position(&current_match, result, get_string("method"), get_long("coord_x"), get_long("coord_y"));
+             cmd_resize(&current_match, result, get_string("way"), get_string("direction"), get_long("resize_px"), get_long("resize_ppt"));
 #else
-           fprintf(stderr, "cmd_move_window_to_position(%s, %ld, %ld)\n", get_string("method"), get_long("coord_x"), get_long("coord_y"));
+           fprintf(stderr, "cmd_resize(%s, %s, %ld, %ld)\n", get_string("way"), get_string("direction"), get_long("resize_px"), get_long("resize_ppt"));
 #endif
              break;
          case 8:
@@ -75,25 +75,25 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 9:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_fullscreen(&current_match, result, "toggle", get_string("mode"));
+             cmd_move_window_to_position(&current_match, result, get_string("method"), get_long("coord_x"), get_long("coord_y"));
 #else
-           fprintf(stderr, "cmd_fullscreen(%s, %s)\n", "toggle", get_string("mode"));
+           fprintf(stderr, "cmd_move_window_to_position(%s, %ld, %ld)\n", get_string("method"), get_long("coord_x"), get_long("coord_y"));
 #endif
              break;
          case 10:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_fullscreen(&current_match, result, "toggle", "output");
+             cmd_fullscreen(&current_match, result, "toggle", get_string("mode"));
 #else
-           fprintf(stderr, "cmd_fullscreen(%s, %s)\n", "toggle", "output");
+           fprintf(stderr, "cmd_fullscreen(%s, %s)\n", "toggle", get_string("mode"));
 #endif
              break;
          case 11:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_move_direction(&current_match, result, get_string("direction"), get_long("pixels"));
+             cmd_fullscreen(&current_match, result, "toggle", "output");
 #else
-           fprintf(stderr, "cmd_move_direction(%s, %ld)\n", get_string("direction"), get_long("pixels"));
+           fprintf(stderr, "cmd_fullscreen(%s, %s)\n", "toggle", "output");
 #endif
              break;
          case 12:
@@ -107,17 +107,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 13:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_move_window_to_center(&current_match, result, get_string("method"));
+             cmd_move_direction(&current_match, result, get_string("direction"), get_long("pixels"));
 #else
-           fprintf(stderr, "cmd_move_window_to_center(%s)\n", get_string("method"));
+           fprintf(stderr, "cmd_move_direction(%s, %ld)\n", get_string("direction"), get_long("pixels"));
 #endif
              break;
          case 14:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_move_window_to_mouse(&current_match, result);
+             cmd_move_window_to_center(&current_match, result, get_string("method"));
 #else
-           fprintf(stderr, "cmd_move_window_to_mouse()\n");
+           fprintf(stderr, "cmd_move_window_to_center(%s)\n", get_string("method"));
 #endif
              break;
          case 15:
@@ -138,13 +138,21 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
              break;
          case 17:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_move_window_to_mouse(&current_match, result);
+#else
+           fprintf(stderr, "cmd_move_window_to_mouse()\n");
+#endif
+             break;
+         case 18:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_workspace_number(&current_match, result, get_string("workspace"), get_string("no_auto_back_and_forth"));
 #else
            fprintf(stderr, "cmd_workspace_number(%s, %s)\n", get_string("workspace"), get_string("no_auto_back_and_forth"));
 #endif
              break;
-         case 18:
+         case 19:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_fullscreen(&current_match, result, get_string("action"), get_string("mode"));
@@ -152,7 +160,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_fullscreen(%s, %s)\n", get_string("action"), get_string("mode"));
 #endif
              break;
-         case 19:
+         case 20:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_fullscreen(&current_match, result, get_string("action"), "output");
@@ -160,7 +168,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_fullscreen(%s, %s)\n", get_string("action"), "output");
 #endif
              break;
-         case 20:
+         case 21:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_move_direction(&current_match, result, get_string("direction"), 10);
@@ -168,20 +176,12 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_move_direction(%s, %d)\n", get_string("direction"), 10);
 #endif
              break;
-         case 21:
+         case 22:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_move_con_to_output(&current_match, result, get_string("output"));
 #else
            fprintf(stderr, "cmd_move_con_to_output(%s)\n", get_string("output"));
-#endif
-             break;
-         case 22:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cmd_move_con_to_workspace(&current_match, result, get_string("workspace"));
-#else
-           fprintf(stderr, "cmd_move_con_to_workspace(%s)\n", get_string("workspace"));
 #endif
              break;
          case 23:
@@ -218,13 +218,21 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
              break;
          case 27:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_move_con_to_workspace(&current_match, result, get_string("workspace"));
+#else
+           fprintf(stderr, "cmd_move_con_to_workspace(%s)\n", get_string("workspace"));
+#endif
+             break;
+         case 28:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_move_con_to_workspace_back_and_forth(&current_match, result);
 #else
            fprintf(stderr, "cmd_move_con_to_workspace_back_and_forth()\n");
 #endif
              break;
-         case 28:
+         case 29:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_move_con_to_workspace_name(&current_match, result, get_string("workspace"), get_string("no_auto_back_and_forth"));
@@ -232,7 +240,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_move_con_to_workspace_name(%s, %s)\n", get_string("workspace"), get_string("no_auto_back_and_forth"));
 #endif
              break;
-         case 29:
+         case 30:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_append_layout(&current_match, result, get_string("path"));
@@ -240,20 +248,12 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_append_layout(%s)\n", get_string("path"));
 #endif
              break;
-         case 30:
+         case 31:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cmd_criteria_add(&current_match, result, get_string("ctype"), get_string("cvalue"));
 #else
            fprintf(stderr, "cmd_criteria_add(%s, %s)\n", get_string("ctype"), get_string("cvalue"));
-#endif
-             break;
-         case 31:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cmd_layout_toggle(&current_match, result, get_string("toggle_mode"));
-#else
-           fprintf(stderr, "cmd_layout_toggle(%s)\n", get_string("toggle_mode"));
 #endif
              break;
          case 32:
@@ -298,13 +298,21 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
              break;
          case 37:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_swap(&current_match, result, get_string("mode"), get_string("arg"));
+#else
+           fprintf(stderr, "cmd_swap(%s, %s)\n", get_string("mode"), get_string("arg"));
+#endif
+             break;
+         case 38:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_border(&current_match, result, get_string("border_style"), 2);
 #else
            fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 2);
 #endif
              break;
-         case 38:
+         case 39:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_border(&current_match, result, get_string("border_style"), get_long("border_width"));
@@ -312,7 +320,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_border(%s, %ld)\n", get_string("border_style"), get_long("border_width"));
 #endif
              break;
-         case 39:
+         case 40:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_focus_output(&current_match, result, get_string("output"));
@@ -320,7 +328,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_focus_output(%s)\n", get_string("output"));
 #endif
              break;
-         case 40:
+         case 41:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_move_con_to_mark(&current_match, result, get_string("mark"));
@@ -328,7 +336,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_move_con_to_mark(%s)\n", get_string("mark"));
 #endif
              break;
-         case 41:
+         case 42:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_title_format(&current_match, result, get_string("format"));
@@ -336,7 +344,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_title_format(%s)\n", get_string("format"));
 #endif
              break;
-         case 42:
+         case 43:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_fullscreen(&current_match, result, get_string("action"), "output");
@@ -344,7 +352,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_fullscreen(%s, %s)\n", get_string("action"), "output");
 #endif
              break;
-         case 43:
+         case 44:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_scratchpad_show(&current_match, result);
@@ -352,20 +360,12 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_scratchpad_show()\n");
 #endif
              break;
-         case 44:
+         case 45:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_resize(&current_match, result, get_string("way"), get_string("direction"), 10, 10);
 #else
            fprintf(stderr, "cmd_resize(%s, %s, %d, %d)\n", get_string("way"), get_string("direction"), 10, 10);
-#endif
-             break;
-         case 45:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cmd_workspace(&current_match, result, get_string("direction"));
-#else
-           fprintf(stderr, "cmd_workspace(%s)\n", get_string("direction"));
 #endif
              break;
          case 46:
@@ -394,13 +394,21 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
              break;
          case 49:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_workspace(&current_match, result, get_string("direction"));
+#else
+           fprintf(stderr, "cmd_workspace(%s)\n", get_string("direction"));
+#endif
+             break;
+         case 50:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_workspace_back_and_forth(&current_match, result);
 #else
            fprintf(stderr, "cmd_workspace_back_and_forth()\n");
 #endif
              break;
-         case 50:
+         case 51:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_workspace_name(&current_match, result, get_string("workspace"), get_string("no_auto_back_and_forth"));
@@ -408,20 +416,12 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_workspace_name(%s, %s)\n", get_string("workspace"), get_string("no_auto_back_and_forth"));
 #endif
              break;
-         case 51:
+         case 52:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_bar(&current_match, result, get_string("bar_type"), get_string("bar_value"), get_string("bar_id"));
 #else
            fprintf(stderr, "cmd_bar(%s, %s, %s)\n", get_string("bar_type"), get_string("bar_value"), get_string("bar_id"));
-#endif
-             break;
-         case 52:
-             result->next_state = CRITERIA;
-#ifndef TEST_PARSER
-             cmd_criteria_add(&current_match, result, get_string("ctype"), NULL);
-#else
-           fprintf(stderr, "cmd_criteria_add(%s, NULL)\n", get_string("ctype"));
 #endif
              break;
          case 53:
@@ -433,19 +433,19 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
 #endif
              break;
          case 54:
-             result->next_state = INITIAL;
+             result->next_state = CRITERIA;
 #ifndef TEST_PARSER
-             cmd_criteria_match_windows(&current_match, result);
+             cmd_criteria_add(&current_match, result, get_string("ctype"), NULL);
 #else
-           fprintf(stderr, "cmd_criteria_match_windows()\n");
+           fprintf(stderr, "cmd_criteria_add(%s, NULL)\n", get_string("ctype"));
 #endif
              break;
          case 55:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_debuglog(&current_match, result, get_string("argument"));
+             cmd_criteria_match_windows(&current_match, result);
 #else
-           fprintf(stderr, "cmd_debuglog(%s)\n", get_string("argument"));
+           fprintf(stderr, "cmd_criteria_match_windows()\n");
 #endif
              break;
          case 56:
@@ -467,9 +467,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 58:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_floating(&current_match, result, get_string("floating"));
+             cmd_debuglog(&current_match, result, get_string("argument"));
 #else
-           fprintf(stderr, "cmd_floating(%s)\n", get_string("floating"));
+           fprintf(stderr, "cmd_debuglog(%s)\n", get_string("argument"));
 #endif
              break;
          case 59:
@@ -489,6 +489,14 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
 #endif
              break;
          case 61:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_floating(&current_match, result, get_string("floating"));
+#else
+           fprintf(stderr, "cmd_floating(%s)\n", get_string("floating"));
+#endif
+             break;
+         case 62:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cmd_criteria_init(&current_match, result);
@@ -496,7 +504,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_criteria_init()\n");
 #endif
              break;
-         case 62:
+         case 63:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_exit(&current_match, result);
@@ -504,7 +512,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_exit()\n");
 #endif
              break;
-         case 63:
+         case 64:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_restart(&current_match, result);
@@ -512,7 +520,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_restart()\n");
 #endif
              break;
-         case 64:
+         case 65:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_reload(&current_match, result);
@@ -520,20 +528,12 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_reload()\n");
 #endif
              break;
-         case 65:
+         case 66:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_open(&current_match, result);
 #else
            fprintf(stderr, "cmd_open()\n");
-#endif
-             break;
-         case 66:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cmd_border(&current_match, result, get_string("border_style"), 0);
-#else
-           fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 0);
 #endif
              break;
          case 67:
@@ -547,17 +547,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 68:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_border(&current_match, result, get_string("border_style"), 1);
+             cmd_border(&current_match, result, get_string("border_style"), 0);
 #else
-           fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 1);
+           fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 0);
 #endif
              break;
          case 69:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_layout(&current_match, result, get_string("layout_mode"));
+             cmd_border(&current_match, result, get_string("border_style"), 1);
 #else
-           fprintf(stderr, "cmd_layout(%s)\n", get_string("layout_mode"));
+           fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 1);
 #endif
              break;
          case 70:
@@ -603,17 +603,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 75:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_shmlog(&current_match, result, get_string("argument"));
+             cmd_layout(&current_match, result, get_string("layout_mode"));
 #else
-           fprintf(stderr, "cmd_shmlog(%s)\n", get_string("argument"));
+           fprintf(stderr, "cmd_layout(%s)\n", get_string("layout_mode"));
 #endif
              break;
          case 76:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_sticky(&current_match, result, get_string("action"));
+             cmd_shmlog(&current_match, result, get_string("argument"));
 #else
-           fprintf(stderr, "cmd_sticky(%s)\n", get_string("action"));
+           fprintf(stderr, "cmd_shmlog(%s)\n", get_string("argument"));
 #endif
              break;
          case 77:
@@ -635,9 +635,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 79:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_unmark(&current_match, result, get_string("mark"));
+             cmd_sticky(&current_match, result, get_string("action"));
 #else
-           fprintf(stderr, "cmd_unmark(%s)\n", get_string("mark"));
+           fprintf(stderr, "cmd_sticky(%s)\n", get_string("action"));
 #endif
              break;
          case 80:
@@ -651,9 +651,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 81:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_focus_direction(&current_match, result, get_string("direction"));
+             cmd_unmark(&current_match, result, get_string("mark"));
 #else
-           fprintf(stderr, "cmd_focus_direction(%s)\n", get_string("direction"));
+           fprintf(stderr, "cmd_unmark(%s)\n", get_string("mark"));
 #endif
              break;
          case 82:
@@ -683,9 +683,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 85:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_focus_window_mode(&current_match, result, get_string("window_mode"));
+             cmd_focus_direction(&current_match, result, get_string("direction"));
 #else
-           fprintf(stderr, "cmd_focus_window_mode(%s)\n", get_string("window_mode"));
+           fprintf(stderr, "cmd_focus_direction(%s)\n", get_string("direction"));
 #endif
              break;
          case 86:
@@ -707,9 +707,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 88:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_focus_level(&current_match, result, get_string("level"));
+             cmd_focus_window_mode(&current_match, result, get_string("window_mode"));
 #else
-           fprintf(stderr, "cmd_focus_level(%s)\n", get_string("level"));
+           fprintf(stderr, "cmd_focus_window_mode(%s)\n", get_string("window_mode"));
 #endif
              break;
          case 89:
@@ -723,17 +723,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 90:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_focus(&current_match, result);
+             cmd_focus_level(&current_match, result, get_string("level"));
 #else
-           fprintf(stderr, "cmd_focus()\n");
+           fprintf(stderr, "cmd_focus_level(%s)\n", get_string("level"));
 #endif
              break;
          case 91:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_split(&current_match, result, get_string("direction"));
+             cmd_focus(&current_match, result);
 #else
-           fprintf(stderr, "cmd_split(%s)\n", get_string("direction"));
+           fprintf(stderr, "cmd_focus()\n");
 #endif
              break;
          case 92:
@@ -779,17 +779,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 97:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_exec(&current_match, result, get_string("nosn"), get_string("command"));
+             cmd_split(&current_match, result, get_string("direction"));
 #else
-           fprintf(stderr, "cmd_exec(%s, %s)\n", get_string("nosn"), get_string("command"));
+           fprintf(stderr, "cmd_split(%s)\n", get_string("direction"));
 #endif
              break;
          case 98:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_kill(&current_match, result, get_string("kill_mode"));
+             cmd_exec(&current_match, result, get_string("nosn"), get_string("command"));
 #else
-           fprintf(stderr, "cmd_kill(%s)\n", get_string("kill_mode"));
+           fprintf(stderr, "cmd_exec(%s, %s)\n", get_string("nosn"), get_string("command"));
 #endif
              break;
          case 99:
@@ -810,13 +810,21 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
              break;
          case 101:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_kill(&current_match, result, get_string("kill_mode"));
+#else
+           fprintf(stderr, "cmd_kill(%s)\n", get_string("kill_mode"));
+#endif
+             break;
+         case 102:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_mark(&current_match, result, get_string("mark"), get_string("mode"), get_string("toggle"));
 #else
            fprintf(stderr, "cmd_mark(%s, %s, %s)\n", get_string("mark"), get_string("mode"), get_string("toggle"));
 #endif
              break;
-         case 102:
+         case 103:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_mode(&current_match, result, get_string("mode"));
@@ -824,7 +832,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_mode(%s)\n", get_string("mode"));
 #endif
              break;
-         case 103:
+         case 104:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_move_scratchpad(&current_match, result);
@@ -832,7 +840,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_move_scratchpad()\n");
 #endif
              break;
-         case 104:
+         case 105:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_nop(&current_match, result, get_string("comment"));
@@ -840,7 +848,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_nop(%s)\n", get_string("comment"));
 #endif
              break;
-         case 105:
+         case 106:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_nop(&current_match, result, NULL);
