@@ -355,9 +355,9 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
          case 44:
              result->next_state = MODE;
 #ifndef TEST_PARSER
-             cfg_mode_binding(&current_match, result, get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("command"));
+             cfg_mode_binding(&current_match, result, get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
 #else
-           fprintf(stderr, "cfg_mode_binding(%s, %s, %s, %s, %s, %s, %s)\n", get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("command"));
+           fprintf(stderr, "cfg_mode_binding(%s, %s, %s, %s, %s, %s, %s, %s)\n", get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
 #endif
              break;
          case 45:
@@ -442,27 +442,27 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
              break;
          case 55:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_disable_randr15(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_disable_randr15(%s)\n", get_string("value"));
+#endif
+             break;
+         case 56:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_force_xinerama(&current_match, result, get_string("value"));
 #else
            fprintf(stderr, "cfg_force_xinerama(%s)\n", get_string("value"));
 #endif
              break;
-         case 56:
+         case 57:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cfg_criteria_add(&current_match, result, get_string("ctype"), get_string("cvalue"));
 #else
            fprintf(stderr, "cfg_criteria_add(%s, %s)\n", get_string("ctype"), get_string("cvalue"));
        cfg_criteria_add(&current_match, result, get_string("ctype"), get_string("cvalue"));
-#endif
-             break;
-         case 57:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_mouse_warping(&current_match, result, get_string("value"));
-#else
-           fprintf(stderr, "cfg_mouse_warping(%s)\n", get_string("value"));
 #endif
              break;
          case 58:
@@ -476,17 +476,17 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
          case 59:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_restart_state(&current_match, result, get_string("path"));
+             cfg_mouse_warping(&current_match, result, get_string("value"));
 #else
-           fprintf(stderr, "cfg_restart_state(%s)\n", get_string("path"));
+           fprintf(stderr, "cfg_mouse_warping(%s)\n", get_string("value"));
 #endif
              break;
          case 60:
-             result->next_state = BAR;
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_bar_modifier(&current_match, result, get_string("modifier"));
+             cfg_restart_state(&current_match, result, get_string("path"));
 #else
-           fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
+           fprintf(stderr, "cfg_restart_state(%s)\n", get_string("path"));
 #endif
              break;
          case 61:
@@ -564,9 +564,9 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
          case 70:
              result->next_state = BAR;
 #ifndef TEST_PARSER
-             cfg_bar_position(&current_match, result, get_string("position"));
+             cfg_bar_modifier(&current_match, result, get_string("modifier"));
 #else
-           fprintf(stderr, "cfg_bar_position(%s)\n", get_string("position"));
+           fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
          case 71:
@@ -578,6 +578,14 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 72:
+             result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_position(&current_match, result, get_string("position"));
+#else
+           fprintf(stderr, "cfg_bar_position(%s)\n", get_string("position"));
+#endif
+             break;
+         case 73:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color_single(&current_match, result, get_string("colorclass"), get_string("color"));
@@ -585,7 +593,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color_single(%s, %s)\n", get_string("colorclass"), get_string("color"));
 #endif
              break;
-         case 73:
+         case 74:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_fake_outputs(&current_match, result, get_string("outputs"));
@@ -593,7 +601,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_fake_outputs(%s)\n", get_string("outputs"));
 #endif
              break;
-         case 74:
+         case 75:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_no_focus(&current_match, result);
@@ -601,7 +609,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_no_focus()\n");
 #endif
              break;
-         case 75:
+         case 76:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_verbose(&current_match, result, get_string("value"));
@@ -609,15 +617,15 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_verbose(%s)\n", get_string("value"));
 #endif
              break;
-         case 76:
+         case 77:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_binding(&current_match, result, get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("command"));
+             cfg_binding(&current_match, result, get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
 #else
-           fprintf(stderr, "cfg_binding(%s, %s, %s, %s, %s, %s, %s)\n", get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("command"));
+           fprintf(stderr, "cfg_binding(%s, %s, %s, %s, %s, %s, %s, %s)\n", get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
 #endif
              break;
-         case 77:
+         case 78:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_output(&current_match, result, get_string("output"));
@@ -625,7 +633,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_output(%s)\n", get_string("output"));
 #endif
              break;
-         case 78:
+         case 79:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cfg_criteria_init(&current_match, result, 27);
@@ -634,20 +642,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_init(&current_match, result, 27);
 #endif
              break;
-         case 79:
+         case 80:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_ipc_socket(&current_match, result, get_string("path"));
 #else
            fprintf(stderr, "cfg_ipc_socket(%s)\n", get_string("path"));
-#endif
-             break;
-         case 80:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_new_window(&current_match, result, get_string("windowtype"), get_string("border"), -1);
-#else
-           fprintf(stderr, "cfg_new_window(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), -1);
 #endif
              break;
          case 81:
@@ -660,13 +660,21 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
              break;
          case 82:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_new_window(&current_match, result, get_string("windowtype"), get_string("border"), -1);
+#else
+           fprintf(stderr, "cfg_new_window(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), -1);
+#endif
+             break;
+         case 83:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_show_marks(&current_match, result, get_string("value"));
 #else
            fprintf(stderr, "cfg_show_marks(%s)\n", get_string("value"));
 #endif
              break;
-         case 83:
+         case 84:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_start(&current_match, result);
@@ -674,20 +682,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_start()\n");
 #endif
              break;
-         case 84:
+         case 85:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_font(&current_match, result, get_string("font"));
 #else
            fprintf(stderr, "cfg_bar_font(%s)\n", get_string("font"));
-#endif
-             break;
-         case 85:
-             result->next_state = BAR;
-#ifndef TEST_PARSER
-             cfg_bar_mode(&current_match, result, get_string("mode"));
-#else
-           fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
 #endif
              break;
          case 86:
@@ -707,12 +707,11 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 88:
-             result->next_state = CRITERIA;
+             result->next_state = BAR;
 #ifndef TEST_PARSER
-             cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
+             cfg_bar_mode(&current_match, result, get_string("mode"));
 #else
-           fprintf(stderr, "cfg_criteria_add(%s, NULL)\n", get_string("ctype"));
-       cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
+           fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
 #endif
              break;
          case 89:
@@ -725,6 +724,15 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 90:
+             result->next_state = CRITERIA;
+#ifndef TEST_PARSER
+             cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
+#else
+           fprintf(stderr, "cfg_criteria_add(%s, NULL)\n", get_string("ctype"));
+       cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
+#endif
+             break;
+         case 91:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_criteria_pop_state(&current_match, result);
@@ -733,7 +741,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_pop_state(&current_match, result);
 #endif
              break;
-         case 91:
+         case 92:
              result->next_state = MODEBRACE;
 #ifndef TEST_PARSER
              cfg_enter_mode(&current_match, result, get_string("pango_markup"), get_string("modename"));
@@ -741,16 +749,16 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_enter_mode(%s, %s)\n", get_string("pango_markup"), get_string("modename"));
 #endif
              break;
-         case 92:
+         case 93:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
-             cfg_criteria_init(&current_match, result, 59);
+             cfg_criteria_init(&current_match, result, 60);
 #else
-           fprintf(stderr, "cfg_criteria_init(%d)\n", 59);
-       cfg_criteria_init(&current_match, result, 59);
+           fprintf(stderr, "cfg_criteria_init(%d)\n", 60);
+       cfg_criteria_init(&current_match, result, 60);
 #endif
              break;
-         case 93:
+         case 94:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cfg_criteria_init(&current_match, result, 33);
@@ -759,7 +767,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_init(&current_match, result, 33);
 #endif
              break;
-         case 94:
+         case 95:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_id(&current_match, result, get_string("bar_id"));
@@ -767,7 +775,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_id(%s)\n", get_string("bar_id"));
 #endif
              break;
-         case 95:
+         case 96:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_exec(&current_match, result, get_string("exectype"), get_string("no_startup_id"), get_string("command"));
@@ -775,7 +783,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_exec(%s, %s, %s)\n", get_string("exectype"), get_string("no_startup_id"), get_string("command"));
 #endif
              break;
-         case 96:
+         case 97:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_font(&current_match, result, get_string("font"));
@@ -783,7 +791,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_font(%s)\n", get_string("font"));
 #endif
              break;
-         case 97:
+         case 98:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_bar_finish(&current_match, result);
