@@ -147,10 +147,11 @@ static cmdp_token tokens_BAR_WHEEL_UP_CMD[1] = {
 static cmdp_token tokens_COLOR_BACKGROUND[1] = {
     { "word", "background", COLOR_TEXT, { 0 } }, 
 };
-static cmdp_token tokens_MODE_BINDCOMMAND[4] = {
+static cmdp_token tokens_MODE_BINDCOMMAND[5] = {
     { "'--release", "release", MODE_BINDCOMMAND, { 0 } }, 
     { "'--border", "border", MODE_BINDCOMMAND, { 0 } }, 
     { "'--whole-window", "whole_window", MODE_BINDCOMMAND, { 0 } }, 
+    { "'--exclude-titlebar", "exclude_titlebar", MODE_BINDCOMMAND, { 0 } }, 
     { "string", "command", __CALL, { 44 } }, 
 };
 static cmdp_token tokens_MODE_IGNORE_LINE[1] = {
@@ -185,48 +186,52 @@ static cmdp_token tokens_COLOR_INDICATOR[2] = {
     { "word", "indicator", COLOR_CHILD_BORDER, { 0 } }, 
     { "end", "", __CALL, { 54 } }, 
 };
-static cmdp_token tokens_FORCE_XINERAMA[1] = {
+static cmdp_token tokens_DISABLE_RANDR15[1] = {
     { "word", "value", __CALL, { 55 } }, 
 };
+static cmdp_token tokens_FORCE_XINERAMA[1] = {
+    { "word", "value", __CALL, { 56 } }, 
+};
 static cmdp_token tokens_CRITERION_STR[1] = {
-    { "word", "cvalue", __CALL, { 56 } }, 
+    { "word", "cvalue", __CALL, { 57 } }, 
 };
 static cmdp_token tokens_MOUSE_WARPING[2] = {
-    { "'none", "value", __CALL, { 57 } }, 
-    { "'output", "value", __CALL, { 58 } }, 
+    { "'none", "value", __CALL, { 58 } }, 
+    { "'output", "value", __CALL, { 59 } }, 
 };
 static cmdp_token tokens_RESTART_STATE[1] = {
-    { "string", "path", __CALL, { 59 } }, 
+    { "string", "path", __CALL, { 60 } }, 
 };
 static cmdp_token tokens_BAR_MODIFIER[10] = {
-    { "'Mod1", "modifier", __CALL, { 60 } }, 
-    { "'Mod2", "modifier", __CALL, { 61 } }, 
-    { "'Mod3", "modifier", __CALL, { 62 } }, 
-    { "'Mod4", "modifier", __CALL, { 63 } }, 
-    { "'Mod5", "modifier", __CALL, { 64 } }, 
-    { "'Control", "modifier", __CALL, { 65 } }, 
-    { "'Ctrl", "modifier", __CALL, { 66 } }, 
-    { "'Shift", "modifier", __CALL, { 67 } }, 
-    { "'none", "modifier", __CALL, { 68 } }, 
-    { "'off", "modifier", __CALL, { 69 } }, 
+    { "'Mod1", "modifier", __CALL, { 61 } }, 
+    { "'Mod2", "modifier", __CALL, { 62 } }, 
+    { "'Mod3", "modifier", __CALL, { 63 } }, 
+    { "'Mod4", "modifier", __CALL, { 64 } }, 
+    { "'Mod5", "modifier", __CALL, { 65 } }, 
+    { "'Control", "modifier", __CALL, { 66 } }, 
+    { "'Ctrl", "modifier", __CALL, { 67 } }, 
+    { "'Shift", "modifier", __CALL, { 68 } }, 
+    { "'none", "modifier", __CALL, { 69 } }, 
+    { "'off", "modifier", __CALL, { 70 } }, 
 };
 static cmdp_token tokens_BAR_POSITION[2] = {
-    { "'top", "position", __CALL, { 70 } }, 
-    { "'bottom", "position", __CALL, { 71 } }, 
+    { "'top", "position", __CALL, { 71 } }, 
+    { "'bottom", "position", __CALL, { 72 } }, 
 };
 static cmdp_token tokens_COLOR_BORDER[1] = {
     { "word", "border", COLOR_BACKGROUND, { 0 } }, 
 };
 static cmdp_token tokens_COLOR_SINGLE[1] = {
-    { "word", "color", __CALL, { 72 } }, 
+    { "word", "color", __CALL, { 73 } }, 
 };
 static cmdp_token tokens_FAKE_OUTPUTS[1] = {
-    { "string", "outputs", __CALL, { 73 } }, 
+    { "string", "outputs", __CALL, { 74 } }, 
 };
-static cmdp_token tokens_MODE_BINDING[19] = {
+static cmdp_token tokens_MODE_BINDING[20] = {
     { "'--release", "release", MODE_BINDING, { 0 } }, 
     { "'--border", "border", MODE_BINDING, { 0 } }, 
     { "'--whole-window", "whole_window", MODE_BINDING, { 0 } }, 
+    { "'--exclude-titlebar", "exclude_titlebar", MODE_BINDING, { 0 } }, 
     { "'Mod1", "modifiers", MODE_BINDING, { 0 } }, 
     { "'Mod2", "modifiers", MODE_BINDING, { 0 } }, 
     { "'Mod3", "modifiers", MODE_BINDING, { 0 } }, 
@@ -245,19 +250,20 @@ static cmdp_token tokens_MODE_BINDING[19] = {
     { "word", "key", MODE_BINDCOMMAND, { 0 } }, 
 };
 static cmdp_token tokens_NO_FOCUS_END[1] = {
-    { "end", "", __CALL, { 74 } }, 
+    { "end", "", __CALL, { 75 } }, 
 };
 static cmdp_token tokens_BAR_BINDSYM[1] = {
     { "word", "button", BAR_BINDSYM_COMMAND, { 0 } }, 
 };
 static cmdp_token tokens_BAR_VERBOSE[1] = {
-    { "word", "value", __CALL, { 75 } }, 
+    { "word", "value", __CALL, { 76 } }, 
 };
-static cmdp_token tokens_BINDCOMMAND[4] = {
+static cmdp_token tokens_BINDCOMMAND[5] = {
     { "'--release", "release", BINDCOMMAND, { 0 } }, 
     { "'--border", "border", BINDCOMMAND, { 0 } }, 
     { "'--whole-window", "whole_window", BINDCOMMAND, { 0 } }, 
-    { "string", "command", __CALL, { 76 } }, 
+    { "'--exclude-titlebar", "exclude_titlebar", BINDCOMMAND, { 0 } }, 
+    { "string", "command", __CALL, { 77 } }, 
 };
 static cmdp_token tokens_IGNORE_LINE[1] = {
     { "line", "", INITIAL, { 0 } }, 
@@ -280,25 +286,25 @@ static cmdp_token tokens_BAR_COLORS[15] = {
     { "'}", "", BAR, { 0 } }, 
 };
 static cmdp_token tokens_BAR_OUTPUT[1] = {
-    { "string", "output", __CALL, { 77 } }, 
+    { "string", "output", __CALL, { 78 } }, 
 };
 static cmdp_token tokens_COLOR_TEXT[1] = {
     { "word", "text", COLOR_INDICATOR, { 0 } }, 
 };
 static cmdp_token tokens_FOR_WINDOW[1] = {
-    { "'[", "", __CALL, { 78 } }, 
+    { "'[", "", __CALL, { 79 } }, 
 };
 static cmdp_token tokens_IPC_SOCKET[1] = {
-    { "string", "path", __CALL, { 79 } }, 
+    { "string", "path", __CALL, { 80 } }, 
 };
 static cmdp_token tokens_NEW_WINDOW[4] = {
     { "'normal", "border", NEW_WINDOW_PIXELS, { 0 } }, 
     { "'pixel", "border", NEW_WINDOW_PIXELS, { 0 } }, 
-    { "'1pixel", "border", __CALL, { 80 } }, 
-    { "'none", "border", __CALL, { 81 } }, 
+    { "'1pixel", "border", __CALL, { 81 } }, 
+    { "'none", "border", __CALL, { 82 } }, 
 };
 static cmdp_token tokens_SHOW_MARKS[1] = {
-    { "word", "value", __CALL, { 82 } }, 
+    { "word", "value", __CALL, { 83 } }, 
 };
 static cmdp_token tokens_CRITERION[1] = {
     { "'=", "", CRITERION_STR, { 0 } }, 
@@ -312,15 +318,15 @@ static cmdp_token tokens_WORKSPACE[1] = {
 };
 static cmdp_token tokens_BARBRACE[2] = {
     { "end", "", BARBRACE, { 0 } }, 
-    { "'{", "", __CALL, { 83 } }, 
+    { "'{", "", __CALL, { 84 } }, 
 };
 static cmdp_token tokens_BAR_FONT[1] = {
-    { "string", "font", __CALL, { 84 } }, 
+    { "string", "font", __CALL, { 85 } }, 
 };
 static cmdp_token tokens_BAR_MODE[3] = {
-    { "'dock", "mode", __CALL, { 85 } }, 
-    { "'hide", "mode", __CALL, { 86 } }, 
-    { "'invisible", "mode", __CALL, { 87 } }, 
+    { "'dock", "mode", __CALL, { 86 } }, 
+    { "'hide", "mode", __CALL, { 87 } }, 
+    { "'invisible", "mode", __CALL, { 88 } }, 
 };
 static cmdp_token tokens_CRITERIA[13] = {
     { "'class", "ctype", CRITERION, { 0 } }, 
@@ -333,21 +339,22 @@ static cmdp_token tokens_CRITERIA[13] = {
     { "'title", "ctype", CRITERION, { 0 } }, 
     { "'urgent", "ctype", CRITERION, { 0 } }, 
     { "'workspace", "ctype", CRITERION, { 0 } }, 
-    { "'tiling", "ctype", __CALL, { 88 } }, 
-    { "'floating", "ctype", __CALL, { 89 } }, 
-    { "']", "", __CALL, { 90 } }, 
+    { "'tiling", "ctype", __CALL, { 89 } }, 
+    { "'floating", "ctype", __CALL, { 90 } }, 
+    { "']", "", __CALL, { 91 } }, 
 };
 static cmdp_token tokens_MODENAME[2] = {
     { "'--pango_markup", "pango_markup", MODENAME, { 0 } }, 
-    { "word", "modename", __CALL, { 91 } }, 
+    { "word", "modename", __CALL, { 92 } }, 
 };
 static cmdp_token tokens_NO_FOCUS[1] = {
-    { "'[", "", __CALL, { 92 } }, 
+    { "'[", "", __CALL, { 93 } }, 
 };
-static cmdp_token tokens_BINDING[19] = {
+static cmdp_token tokens_BINDING[20] = {
     { "'--release", "release", BINDING, { 0 } }, 
     { "'--border", "border", BINDING, { 0 } }, 
     { "'--whole-window", "whole_window", BINDING, { 0 } }, 
+    { "'--exclude-titlebar", "exclude_titlebar", BINDING, { 0 } }, 
     { "'Mod1", "modifiers", BINDING, { 0 } }, 
     { "'Mod2", "modifiers", BINDING, { 0 } }, 
     { "'Mod3", "modifiers", BINDING, { 0 } }, 
@@ -365,11 +372,12 @@ static cmdp_token tokens_BINDING[19] = {
     { "'+", "", BINDING, { 0 } }, 
     { "word", "key", BINDCOMMAND, { 0 } }, 
 };
-static cmdp_token tokens_INITIAL[46] = {
+static cmdp_token tokens_INITIAL[49] = {
     { "end", "", INITIAL, { 0 } }, 
     { "error", "", INITIAL, { 0 } }, 
     { "'#", "", IGNORE_LINE, { 0 } }, 
-    { "'set", "", IGNORE_LINE, { 0 } }, 
+    { "'set ", "", IGNORE_LINE, { 0 } }, 
+    { "'set	", "", IGNORE_LINE, { 0 } }, 
     { "'set_from_resource", "", IGNORE_LINE, { 0 } }, 
     { "'bindsym", "bindtype", BINDING, { 0 } }, 
     { "'bindcode", "bindtype", BINDING, { 0 } }, 
@@ -393,6 +401,8 @@ static cmdp_token tokens_INITIAL[46] = {
     { "'force_focus_wrapping", "", FORCE_FOCUS_WRAPPING, { 0 } }, 
     { "'force_xinerama", "", FORCE_XINERAMA, { 0 } }, 
     { "'force-xinerama", "", FORCE_XINERAMA, { 0 } }, 
+    { "'disable_randr15", "", DISABLE_RANDR15, { 0 } }, 
+    { "'disable-randr15", "", DISABLE_RANDR15, { 0 } }, 
     { "'workspace_auto_back_and_forth", "", WORKSPACE_BACK_AND_FORTH, { 0 } }, 
     { "'fake_outputs", "", FAKE_OUTPUTS, { 0 } }, 
     { "'fake-outputs", "", FAKE_OUTPUTS, { 0 } }, 
@@ -414,17 +424,17 @@ static cmdp_token tokens_INITIAL[46] = {
     { "'client.placeholder", "colorclass", COLOR_BORDER, { 0 } }, 
 };
 static cmdp_token tokens_ASSIGN[1] = {
-    { "'[", "", __CALL, { 93 } }, 
+    { "'[", "", __CALL, { 94 } }, 
 };
 static cmdp_token tokens_BAR_ID[1] = {
-    { "word", "bar_id", __CALL, { 94 } }, 
+    { "word", "bar_id", __CALL, { 95 } }, 
 };
 static cmdp_token tokens_EXEC[2] = {
     { "'--no-startup-id", "no_startup_id", EXEC, { 0 } }, 
-    { "string", "command", __CALL, { 95 } }, 
+    { "string", "command", __CALL, { 96 } }, 
 };
 static cmdp_token tokens_FONT[1] = {
-    { "string", "font", __CALL, { 96 } }, 
+    { "string", "font", __CALL, { 97 } }, 
 };
 static cmdp_token tokens_MODE[8] = {
     { "end", "", MODE, { 0 } }, 
@@ -462,9 +472,9 @@ static cmdp_token tokens_BAR[26] = {
     { "'strip_workspace_numbers", "", BAR_STRIP_WORKSPACE_NUMBERS, { 0 } }, 
     { "'verbose", "", BAR_VERBOSE, { 0 } }, 
     { "'colors", "", BAR_COLORS_BRACE, { 0 } }, 
-    { "'}", "", __CALL, { 97 } }, 
+    { "'}", "", __CALL, { 98 } }, 
 };
-static cmdp_token_ptr tokens[88] = {
+static cmdp_token_ptr tokens[89] = {
     { tokens_FORCE_DISPLAY_URGENCY_HINT_MS, 2 },
     { tokens_FLOATING_MAXIMUM_SIZE_HEIGHT, 1 },
     { tokens_FLOATING_MINIMUM_SIZE_HEIGHT, 1 },
@@ -504,7 +514,7 @@ static cmdp_token_ptr tokens[88] = {
     { tokens_BAR_TRAY_PADDING, 1 },
     { tokens_BAR_WHEEL_UP_CMD, 1 },
     { tokens_COLOR_BACKGROUND, 1 },
-    { tokens_MODE_BINDCOMMAND, 4 },
+    { tokens_MODE_BINDCOMMAND, 5 },
     { tokens_MODE_IGNORE_LINE, 1 },
     { tokens_WORKSPACE_LAYOUT, 4 },
     { tokens_WORKSPACE_OUTPUT, 1 },
@@ -514,6 +524,7 @@ static cmdp_token_ptr tokens[88] = {
     { tokens_BAR_SOCKET_PATH, 1 },
     { tokens_BAR_TRAY_OUTPUT, 1 },
     { tokens_COLOR_INDICATOR, 2 },
+    { tokens_DISABLE_RANDR15, 1 },
     { tokens_FORCE_XINERAMA, 1 },
     { tokens_CRITERION_STR, 1 },
     { tokens_MOUSE_WARPING, 2 },
@@ -523,11 +534,11 @@ static cmdp_token_ptr tokens[88] = {
     { tokens_COLOR_BORDER, 1 },
     { tokens_COLOR_SINGLE, 1 },
     { tokens_FAKE_OUTPUTS, 1 },
-    { tokens_MODE_BINDING, 19 },
+    { tokens_MODE_BINDING, 20 },
     { tokens_NO_FOCUS_END, 1 },
     { tokens_BAR_BINDSYM, 1 },
     { tokens_BAR_VERBOSE, 1 },
-    { tokens_BINDCOMMAND, 4 },
+    { tokens_BINDCOMMAND, 5 },
     { tokens_IGNORE_LINE, 1 },
     { tokens_BAR_COLORS, 15 },
     { tokens_BAR_OUTPUT, 1 },
@@ -545,8 +556,8 @@ static cmdp_token_ptr tokens[88] = {
     { tokens_CRITERIA, 13 },
     { tokens_MODENAME, 2 },
     { tokens_NO_FOCUS, 1 },
-    { tokens_BINDING, 19 },
-    { tokens_INITIAL, 46 },
+    { tokens_BINDING, 20 },
+    { tokens_INITIAL, 49 },
     { tokens_ASSIGN, 1 },
     { tokens_BAR_ID, 1 },
     { tokens_EXEC, 2 },
